Example files for I/O tests
---------------------------

- `dust_subsection` : Contains a subsection of the SFD map. The code
  expects a specific filename, so the file is in a subdirectory to
  make it clear that it is a subsection of the original file.

- `salt2_example.dat` : Example `lc-03D4ag.list` from
  http://supernovae.in2p3.fr/salt/doku.php?id=usage

- `SNLS3-04D3gx` : Example data from SNLS3-04D3gx, distributed with
  SALT2 data.

